# Core

***

## Description
Core test for vitor deployment and uploading process

## Installation
Install Python 3.9 and miniconda 3

## Usage
conda install vitor-core and import into your project.

## Support
For support on this project go to https://www.oss-group.co.nz/.

## License
License for this project can be found at https://gitlab.com/vitorpinel/core/-/blob/main/LICENSE.

## Project status
Project has started and in full development process